@@ -34,6 +34,8 @@
 
 '''
 '''
+from __future__ import division
+from builtins import str
 
 __docformat__ = 'restructuredtext'
 __version__ = '$Id: $'
@@ -330,7 +332,7 @@ class CarbonWindow(BaseWindow):
         # Can occur when mixing with other toolkits, e.g. Tk.
         # Fixes issue 180.
         if result not in (eventLoopTimedOutErr, eventLoopQuitErr):
-            raise 'Error %d' % result
+            raise WindowException('Error %d' % result)
 
     def dispatch_pending_events(self):
         while self._event_queue:
@@ -653,7 +655,7 @@ class CarbonWindow(BaseWindow):
                 self.dispatch_event('on_text_motion_select', motion)
             else:
                 self.dispatch_event('on_text_motion', motion)
-        elif ((unicodedata.category(text[0]) != 'Cc' or text == '\r') and
+        elif ((unicodedata.category(text[0]) != 'Cc' or text == u'\r') and
             not (modifiers & key.MOD_COMMAND)):
             self.dispatch_event('on_text', text)
         return noErr
@@ -688,7 +690,7 @@ class CarbonWindow(BaseWindow):
             wchar = None
         # If the unicode char is within charmap keys (ascii value), then we use
         # the corresponding symbol.
-        if wchar in list(charmap.keys()):
+        if wchar in charmap.keys():
             symbol = charmap[wchar]
         else:
             sym = c_uint32()
